Class: Azure::BatchAI::Mgmt::V2018_03_01::Models::EnvironmentVariableWithSecretValue

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb

Overview

A collection of environment variables with secret values to set.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#nameString

secret value.

Returns:

  • (String)

    The name of the environment variable to store the



17
18
19
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 17

def name
  @name
end

#valueString

never be reported back by Batch AI.

Returns:

  • (String)

    The value of the environment variable. This value will



21
22
23
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 21

def value
  @value
end

#value_secret_referenceKeyVaultSecretReference

KeyVault secret which will be used as the environment variable value. Specifies KeyVault Store and Secret which contains the value for the environment variable. One of value or valueSecretReference must be provided.

Returns:



28
29
30
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 28

def value_secret_reference
  @value_secret_reference
end

Class Method Details

.mapperObject

Mapper for EnvironmentVariableWithSecretValue class as Ruby Hash. This will be used for serialization/deserialization.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 35

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'EnvironmentVariableWithSecretValue',
    type: {
      name: 'Composite',
      class_name: 'EnvironmentVariableWithSecretValue',
      model_properties: {
        name: {
          client_side_validation: true,
          required: true,
          serialized_name: 'name',
          type: {
            name: 'String'
          }
        },
        value: {
          client_side_validation: true,
          required: false,
          serialized_name: 'value',
          type: {
            name: 'String'
          }
        },
        value_secret_reference: {
          client_side_validation: true,
          required: false,
          serialized_name: 'valueSecretReference',
          type: {
            name: 'Composite',
            class_name: 'KeyVaultSecretReference'
          }
        }
      }
    }
  }
end