Class: Azure::BatchAI::Mgmt::V2018_03_01::Models::InputDirectory
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_03_01::Models::InputDirectory
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-03-01/generated/azure_mgmt_batchai/models/input_directory.rb
Overview
Input directory for the job.
Instance Attribute Summary collapse
-
#id ⇒ String
directory will be available as a value of an environment variable with AZ_BATCHAI_INPUT_<id> name, where <id> is the value of id attribute.
-
#path ⇒ String
The path to the input directory.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for InputDirectory class as Ruby Hash.
Instance Attribute Details
#id ⇒ String
directory will be available as a value of an environment variable with AZ_BATCHAI_INPUT_<id> name, where <id> is the value of id attribute.
18 19 20 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/input_directory.rb', line 18 def id @id end |
#path ⇒ String
Returns The path to the input directory.
21 22 23 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/input_directory.rb', line 21 def path @path end |
Class Method Details
.mapper ⇒ Object
Mapper for InputDirectory class as Ruby Hash. This will be used for serialization/deserialization.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/input_directory.rb', line 28 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'InputDirectory', type: { name: 'Composite', class_name: 'InputDirectory', model_properties: { id: { client_side_validation: true, required: true, serialized_name: 'id', type: { name: 'String' } }, path: { client_side_validation: true, required: true, serialized_name: 'path', type: { name: 'String' } } } } } end |