Class: Azure::BatchAI::Mgmt::V2018_03_01::Models::JobCreateParameters

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb

Overview

Parameters supplied to the Create operation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#caffe2settingsCaffe2Settings

Returns Specifies the settings for Caffe2 job.

Returns:



66
67
68
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 66

def caffe2settings
  @caffe2settings
end

#caffe_settingsCaffeSettings

Returns Specifies the settings for Caffe job.

Returns:



63
64
65
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 63

def caffe_settings
  @caffe_settings
end

#chainer_settingsChainerSettings

Returns Specifies the settings for Chainer job.

Returns:



69
70
71
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 69

def chainer_settings
  @chainer_settings
end

#clusterResourceId

will run.

Returns:

  • (ResourceId)

    Specifies the Id of the cluster on which this job



33
34
35
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 33

def cluster
  @cluster
end

#cntk_settingsCNTKsettings

Cognitive Toolkit) job.

Returns:

  • (CNTKsettings)

    Specifies the settings for CNTK (aka Microsoft



53
54
55
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 53

def cntk_settings
  @cntk_settings
end

#constraintsJobBasePropertiesConstraints

Job.

Returns:



105
106
107
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 105

def constraints
  @constraints
end

#container_settingsContainerSettings

specified container. If the container was downloaded as part of cluster setup then the same container image will be used. If not provided, the job will run on the VM.

Returns:



49
50
51
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 49

def container_settings
  @container_settings
end

#custom_toolkit_settingsCustomToolkitSettings

kit job.

Returns:



73
74
75
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 73

def custom_toolkit_settings
  @custom_toolkit_settings
end

#environment_variablesArray<EnvironmentVariable>

to set on the job. Batch AI will setup these additional environment variables for the job.

Returns:



95
96
97
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 95

def environment_variables
  @environment_variables
end

#experiment_nameString

Returns Describe the experiment information of the job.

Returns:

  • (String)

    Describe the experiment information of the job



23
24
25
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 23

def experiment_name
  @experiment_name
end

#input_directoriesArray<InputDirectory>

for the Job.

Returns:



86
87
88
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 86

def input_directories
  @input_directories
end

#job_preparationJobPreparation

before tool kit is launched. The specified actions will run on all the nodes that are part of the job

Returns:



78
79
80
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 78

def job_preparation
  @job_preparation
end

#locationString

Returns The region in which to create the job.

Returns:

  • (String)

    The region in which to create the job.



16
17
18
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 16

def location
  @location
end

#mount_volumesMountVolumes

job. These volumes will be mounted before the job execution and will be unmounted after the job completion. The volumes will be mounted at location specified by $AZ_BATCHAI_JOB_MOUNT_ROOT environment variable.

Returns:

  • (MountVolumes)

    Information on mount volumes to be used by the



39
40
41
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 39

def mount_volumes
  @mount_volumes
end

#node_countInteger

will be gang scheduled on that many compute nodes

Returns:

  • (Integer)

    Number of compute nodes to run the job on. The job



43
44
45
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 43

def node_count
  @node_count
end

#output_directoriesArray<OutputDirectory>

directories.

Returns:



90
91
92
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 90

def output_directories
  @output_directories
end

#priorityInteger

with the job. Priority values can range from -1000 to 1000, with -1000 being the lowest priority and 1000 being the highest priority. The default value is 0. Default value: 0 .

Returns:

  • (Integer)

    Priority associated with the job. Priority associated



29
30
31
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 29

def priority
  @priority
end

#py_torch_settingsPyTorchSettings

Returns Specifies the settings for pyTorch job.

Returns:



56
57
58
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 56

def py_torch_settings
  @py_torch_settings
end

#secretsArray<EnvironmentVariableWithSecretValue>

environment variables with secret values to set on the job. Batch AI will setup these additional environment variables for the job. Server will never report values of these variables back.

Returns:



101
102
103
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 101

def secrets
  @secrets
end

#std_out_err_path_prefixString

and stderror of the job.

Returns:

  • (String)

    The path where the Batch AI service will upload stdout



82
83
84
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 82

def std_out_err_path_prefix
  @std_out_err_path_prefix
end

#tagsHash{String => String}

with the job.

Returns:

  • (Hash{String => String})

    The user specified tags associated



20
21
22
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 20

def tags
  @tags
end

#tensor_flow_settingsTensorFlowSettings

job.

Returns:



60
61
62
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 60

def tensor_flow_settings
  @tensor_flow_settings
end

Class Method Details

.mapperObject

Mapper for JobCreateParameters class as Ruby Hash. This will be used for serialization/deserialization.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 112

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'JobCreateParameters',
    type: {
      name: 'Composite',
      class_name: 'JobCreateParameters',
      model_properties: {
        location: {
          client_side_validation: true,
          required: true,
          serialized_name: 'location',
          type: {
            name: 'String'
          }
        },
        tags: {
          client_side_validation: true,
          required: false,
          serialized_name: 'tags',
          type: {
            name: 'Dictionary',
            value: {
                client_side_validation: true,
                required: false,
                serialized_name: 'StringElementType',
                type: {
                  name: 'String'
                }
            }
          }
        },
        experiment_name: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.experimentName',
          type: {
            name: 'String'
          }
        },
        priority: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.priority',
          default_value: 0,
          type: {
            name: 'Number'
          }
        },
        cluster: {
          client_side_validation: true,
          required: true,
          serialized_name: 'properties.cluster',
          type: {
            name: 'Composite',
            class_name: 'ResourceId'
          }
        },
        mount_volumes: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.mountVolumes',
          type: {
            name: 'Composite',
            class_name: 'MountVolumes'
          }
        },
        node_count: {
          client_side_validation: true,
          required: true,
          serialized_name: 'properties.nodeCount',
          type: {
            name: 'Number'
          }
        },
        container_settings: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.containerSettings',
          type: {
            name: 'Composite',
            class_name: 'ContainerSettings'
          }
        },
        cntk_settings: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.cntkSettings',
          type: {
            name: 'Composite',
            class_name: 'CNTKsettings'
          }
        },
        py_torch_settings: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.pyTorchSettings',
          type: {
            name: 'Composite',
            class_name: 'PyTorchSettings'
          }
        },
        tensor_flow_settings: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.tensorFlowSettings',
          type: {
            name: 'Composite',
            class_name: 'TensorFlowSettings'
          }
        },
        caffe_settings: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.caffeSettings',
          type: {
            name: 'Composite',
            class_name: 'CaffeSettings'
          }
        },
        caffe2settings: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.caffe2Settings',
          type: {
            name: 'Composite',
            class_name: 'Caffe2Settings'
          }
        },
        chainer_settings: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.chainerSettings',
          type: {
            name: 'Composite',
            class_name: 'ChainerSettings'
          }
        },
        custom_toolkit_settings: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.customToolkitSettings',
          type: {
            name: 'Composite',
            class_name: 'CustomToolkitSettings'
          }
        },
        job_preparation: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.jobPreparation',
          type: {
            name: 'Composite',
            class_name: 'JobPreparation'
          }
        },
        std_out_err_path_prefix: {
          client_side_validation: true,
          required: true,
          serialized_name: 'properties.stdOutErrPathPrefix',
          type: {
            name: 'String'
          }
        },
        input_directories: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.inputDirectories',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'InputDirectoryElementType',
                type: {
                  name: 'Composite',
                  class_name: 'InputDirectory'
                }
            }
          }
        },
        output_directories: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.outputDirectories',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'OutputDirectoryElementType',
                type: {
                  name: 'Composite',
                  class_name: 'OutputDirectory'
                }
            }
          }
        },
        environment_variables: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.environmentVariables',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'EnvironmentVariableElementType',
                type: {
                  name: 'Composite',
                  class_name: 'EnvironmentVariable'
                }
            }
          }
        },
        secrets: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.secrets',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'EnvironmentVariableWithSecretValueElementType',
                type: {
                  name: 'Composite',
                  class_name: 'EnvironmentVariableWithSecretValue'
                }
            }
          }
        },
        constraints: {
          client_side_validation: true,
          required: false,
          serialized_name: 'properties.constraints',
          type: {
            name: 'Composite',
            class_name: 'JobBasePropertiesConstraints'
          }
        }
      }
    }
  }
end