Class: Azure::BatchAI::Mgmt::V2018_03_01::Models::NodeSetup
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_03_01::Models::NodeSetup
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-03-01/generated/azure_mgmt_batchai/models/node_setup.rb
Overview
Use this to prepare the VM. NOTE: The volumes specified in mountVolumes are mounted first and then the setupTask is run. Therefore the setup task can use local mountPaths in its execution.
Instance Attribute Summary collapse
-
#mount_volumes ⇒ MountVolumes
jobs.
-
#performance_counters_settings ⇒ PerformanceCountersSettings
performance counters collecting and uploading.
-
#setup_task ⇒ SetupTask
customize the compute nodes of the cluster.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for NodeSetup class as Ruby Hash.
Instance Attribute Details
#mount_volumes ⇒ MountVolumes
jobs. Specified mount volumes will be available to all jobs executing on the cluster. The volumes will be mounted at location specified by $AZ_BATCHAI_MOUNT_ROOT environment variable.
29 30 31 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/node_setup.rb', line 29 def mount_volumes @mount_volumes end |
#performance_counters_settings ⇒ PerformanceCountersSettings
performance counters collecting and uploading.
33 34 35 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/node_setup.rb', line 33 def performance_counters_settings @performance_counters_settings end |
#setup_task ⇒ SetupTask
customize the compute nodes of the cluster. The NodeSetup task runs every time a VM is rebooted. For that reason the task code needs to be idempotent. Generally it is used to either download static data that is required for all jobs that run on the cluster VMs or to download/install software.
23 24 25 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/node_setup.rb', line 23 def setup_task @setup_task end |
Class Method Details
.mapper ⇒ Object
Mapper for NodeSetup class as Ruby Hash. This will be used for serialization/deserialization.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/node_setup.rb', line 40 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'NodeSetup', type: { name: 'Composite', class_name: 'NodeSetup', model_properties: { setup_task: { client_side_validation: true, required: false, serialized_name: 'setupTask', type: { name: 'Composite', class_name: 'SetupTask' } }, mount_volumes: { client_side_validation: true, required: false, serialized_name: 'mountVolumes', type: { name: 'Composite', class_name: 'MountVolumes' } }, performance_counters_settings: { client_side_validation: true, required: false, serialized_name: 'performanceCountersSettings', type: { name: 'Composite', class_name: 'PerformanceCountersSettings' } } } } } end |