Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::AzureBlobFileSystemReference
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_05_01::Models::AzureBlobFileSystemReference
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_blob_file_system_reference.rb
Overview
Azure Blob Storage Container mounting configuration.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account name.
-
#container_name ⇒ String
container to mount on the cluster.
-
#credentials ⇒ AzureStorageCredentialsInfo
the Azure storage credentials.
-
#mount_options ⇒ String
file system.
-
#relative_mount_path ⇒ String
node where the Azure File container will be mounted.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for AzureBlobFileSystemReference class as Ruby Hash.
Instance Attribute Details
#account_name ⇒ String
Returns Account name. Name of the Azure storage account.
16 17 18 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_blob_file_system_reference.rb', line 16 def account_name @account_name end |
#container_name ⇒ String
container to mount on the cluster.
20 21 22 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_blob_file_system_reference.rb', line 20 def container_name @container_name end |
#credentials ⇒ AzureStorageCredentialsInfo
the Azure storage credentials.
24 25 26 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_blob_file_system_reference.rb', line 24 def credentials @credentials end |
#mount_options ⇒ String
file system.
35 36 37 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_blob_file_system_reference.rb', line 35 def @mount_options end |
#relative_mount_path ⇒ String
node where the Azure File container will be mounted. Note that all cluster level containers will be mounted under $AZ_BATCHAI_MOUNT_ROOT location and all job level containers will be mounted under $AZ_BATCHAI_JOB_MOUNT_ROOT.
31 32 33 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_blob_file_system_reference.rb', line 31 def relative_mount_path @relative_mount_path end |
Class Method Details
.mapper ⇒ Object
Mapper for AzureBlobFileSystemReference class as Ruby Hash. This will be used for serialization/deserialization.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_blob_file_system_reference.rb', line 42 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'AzureBlobFileSystemReference', type: { name: 'Composite', class_name: 'AzureBlobFileSystemReference', model_properties: { account_name: { client_side_validation: true, required: true, serialized_name: 'accountName', type: { name: 'String' } }, container_name: { client_side_validation: true, required: true, serialized_name: 'containerName', type: { name: 'String' } }, credentials: { client_side_validation: true, required: true, serialized_name: 'credentials', type: { name: 'Composite', class_name: 'AzureStorageCredentialsInfo' } }, relative_mount_path: { client_side_validation: true, required: true, serialized_name: 'relativeMountPath', type: { name: 'String' } }, mount_options: { client_side_validation: true, required: false, serialized_name: 'mountOptions', type: { name: 'String' } } } } } end |