Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::AzureFileShareReference
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_05_01::Models::AzureFileShareReference
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_file_share_reference.rb
Overview
Azure File Share mounting configuration.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account name.
-
#azure_file_url ⇒ String
Azure File URL.
-
#credentials ⇒ AzureStorageCredentialsInfo
the Azure storage credentials.
-
#directory_mode ⇒ String
mounted file share.
-
#file_mode ⇒ String
share.
-
#relative_mount_path ⇒ String
node where the Azure File share will be mounted.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for AzureFileShareReference class as Ruby Hash.
Instance Attribute Details
#account_name ⇒ String
16 17 18 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_file_share_reference.rb', line 16 def account_name @account_name end |
#azure_file_url ⇒ String
19 20 21 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_file_share_reference.rb', line 19 def azure_file_url @azure_file_url end |
#credentials ⇒ AzureStorageCredentialsInfo
the Azure storage credentials.
23 24 25 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_file_share_reference.rb', line 23 def credentials @credentials end |
#directory_mode ⇒ String
mounted file share. Default value: 0777. Default value: ‘0777’ .
38 39 40 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_file_share_reference.rb', line 38 def directory_mode @directory_mode end |
#file_mode ⇒ String
share. Default value: 0777. Default value: ‘0777’ .
34 35 36 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_file_share_reference.rb', line 34 def file_mode @file_mode end |
#relative_mount_path ⇒ String
node where the Azure File share will be mounted. Note that all cluster level file shares will be mounted under $AZ_BATCHAI_MOUNT_ROOT location and all job level file shares will be mounted under $AZ_BATCHAI_JOB_MOUNT_ROOT.
30 31 32 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_file_share_reference.rb', line 30 def relative_mount_path @relative_mount_path end |
Class Method Details
.mapper ⇒ Object
Mapper for AzureFileShareReference class as Ruby Hash. This will be used for serialization/deserialization.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/azure_file_share_reference.rb', line 45 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'AzureFileShareReference', type: { name: 'Composite', class_name: 'AzureFileShareReference', model_properties: { account_name: { client_side_validation: true, required: true, serialized_name: 'accountName', type: { name: 'String' } }, azure_file_url: { client_side_validation: true, required: true, serialized_name: 'azureFileUrl', type: { name: 'String' } }, credentials: { client_side_validation: true, required: true, serialized_name: 'credentials', type: { name: 'Composite', class_name: 'AzureStorageCredentialsInfo' } }, relative_mount_path: { client_side_validation: true, required: true, serialized_name: 'relativeMountPath', type: { name: 'String' } }, file_mode: { client_side_validation: true, required: false, serialized_name: 'fileMode', default_value: '0777', type: { name: 'String' } }, directory_mode: { client_side_validation: true, required: false, serialized_name: 'directoryMode', default_value: '0777', type: { name: 'String' } } } } } end |