Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::ClusterCreateParameters
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_05_01::Models::ClusterCreateParameters
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-05-01/generated/azure_mgmt_batchai/models/cluster_create_parameters.rb
Overview
Cluster creation operation.
Instance Attribute Summary collapse
-
#node_setup ⇒ NodeSetup
node in the cluster.
-
#scale_settings ⇒ ScaleSettings
Batch AI service supports manual and auto scale clusters.
-
#subnet ⇒ ResourceId
cluster nodes in.
-
#user_account_settings ⇒ UserAccountSettings
administrator user account that will be created on each compute node in the cluster.
-
#virtual_machine_configuration ⇒ VirtualMachineConfiguration
configuration for cluster nodes.
-
#vm_priority ⇒ VmPriority
dedicated (default) and lowpriority.
-
#vm_size ⇒ String
cluster.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for ClusterCreateParameters class as Ruby Hash.
Instance Attribute Details
#node_setup ⇒ NodeSetup
node in the cluster.
39 40 41 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/cluster_create_parameters.rb', line 39 def node_setup @node_setup end |
#scale_settings ⇒ ScaleSettings
Batch AI service supports manual and auto scale clusters.
30 31 32 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/cluster_create_parameters.rb', line 30 def scale_settings @scale_settings end |
#subnet ⇒ ResourceId
cluster nodes in. Note, if a File Server mount configured in node setup, the File Server’s subnet will be used automatically.
49 50 51 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/cluster_create_parameters.rb', line 49 def subnet @subnet end |
#user_account_settings ⇒ UserAccountSettings
administrator user account that will be created on each compute node in the cluster.
44 45 46 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/cluster_create_parameters.rb', line 44 def user_account_settings @user_account_settings end |
#virtual_machine_configuration ⇒ VirtualMachineConfiguration
configuration for cluster nodes. All nodes in a cluster have the same OS image.
35 36 37 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/cluster_create_parameters.rb', line 35 def virtual_machine_configuration @virtual_machine_configuration end |
#vm_priority ⇒ VmPriority
dedicated (default) and lowpriority. Possible values include: ‘dedicated’, ‘lowpriority’. Default value: ‘dedicated’ .
26 27 28 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/cluster_create_parameters.rb', line 26 def vm_priority @vm_priority end |
#vm_size ⇒ String
cluster. All nodes in a cluster have the same VM size. For information about available VM sizes for clusters using images from the Virtual Machines Marketplace see Sizes for Virtual Machines (Linux). Batch AI service supports all Azure VM sizes except STANDARD_A0 and those with premium storage (STANDARD_GS, STANDARD_DS, and STANDARD_DSV2 series).
21 22 23 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/cluster_create_parameters.rb', line 21 def vm_size @vm_size end |
Class Method Details
.mapper ⇒ Object
Mapper for ClusterCreateParameters class as Ruby Hash. This will be used for serialization/deserialization.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/cluster_create_parameters.rb', line 56 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'ClusterCreateParameters', type: { name: 'Composite', class_name: 'ClusterCreateParameters', model_properties: { vm_size: { client_side_validation: true, required: true, serialized_name: 'properties.vmSize', type: { name: 'String' } }, vm_priority: { client_side_validation: true, required: false, serialized_name: 'properties.vmPriority', default_value: 'dedicated', type: { name: 'Enum', module: 'VmPriority' } }, scale_settings: { client_side_validation: true, required: false, serialized_name: 'properties.scaleSettings', type: { name: 'Composite', class_name: 'ScaleSettings' } }, virtual_machine_configuration: { client_side_validation: true, required: false, serialized_name: 'properties.virtualMachineConfiguration', type: { name: 'Composite', class_name: 'VirtualMachineConfiguration' } }, node_setup: { client_side_validation: true, required: false, serialized_name: 'properties.nodeSetup', type: { name: 'Composite', class_name: 'NodeSetup' } }, user_account_settings: { client_side_validation: true, required: true, serialized_name: 'properties.userAccountSettings', type: { name: 'Composite', class_name: 'UserAccountSettings' } }, subnet: { client_side_validation: true, required: false, serialized_name: 'properties.subnet', type: { name: 'Composite', class_name: 'ResourceId' } } } } } end |