Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::FileServerCreateParameters
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_05_01::Models::FileServerCreateParameters
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-05-01/generated/azure_mgmt_batchai/models/file_server_create_parameters.rb
Overview
File Server creation parameters.
Instance Attribute Summary collapse
-
#data_disks ⇒ DataDisks
be created for the File Server.
-
#ssh_configuration ⇒ SshConfiguration
File Server node.
-
#subnet ⇒ ResourceId
virtual network subnet to put the File Server in.
-
#vm_size ⇒ String
Server.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for FileServerCreateParameters class as Ruby Hash.
Instance Attribute Details
#data_disks ⇒ DataDisks
be created for the File Server.
26 27 28 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/file_server_create_parameters.rb', line 26 def data_disks @data_disks end |
#ssh_configuration ⇒ SshConfiguration
File Server node.
22 23 24 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/file_server_create_parameters.rb', line 22 def ssh_configuration @ssh_configuration end |
#subnet ⇒ ResourceId
virtual network subnet to put the File Server in. If not provided, a new virtual network and subnet will be created.
31 32 33 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/file_server_create_parameters.rb', line 31 def subnet @subnet end |
#vm_size ⇒ String
Server. For information about available VM sizes from the Virtual Machines Marketplace, see Sizes for Virtual Machines (Linux).
18 19 20 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/file_server_create_parameters.rb', line 18 def vm_size @vm_size end |
Class Method Details
.mapper ⇒ Object
Mapper for FileServerCreateParameters class as Ruby Hash. This will be used for serialization/deserialization.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/file_server_create_parameters.rb', line 38 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'FileServerCreateParameters', type: { name: 'Composite', class_name: 'FileServerCreateParameters', model_properties: { vm_size: { client_side_validation: true, required: true, serialized_name: 'properties.vmSize', type: { name: 'String' } }, ssh_configuration: { client_side_validation: true, required: true, serialized_name: 'properties.sshConfiguration', type: { name: 'Composite', class_name: 'SshConfiguration' } }, data_disks: { client_side_validation: true, required: true, serialized_name: 'properties.dataDisks', type: { name: 'Composite', class_name: 'DataDisks' } }, subnet: { client_side_validation: true, required: false, serialized_name: 'properties.subnet', type: { name: 'Composite', class_name: 'ResourceId' } } } } } end |