Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::ImageReference
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_05_01::Models::ImageReference
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-05-01/generated/azure_mgmt_batchai/models/image_reference.rb
Overview
The OS image reference.
Instance Attribute Summary collapse
-
#offer ⇒ String
Offer.
-
#publisher ⇒ String
Publisher.
-
#sku ⇒ String
SKU.
-
#version ⇒ String
Version.
-
#virtual_machine_image_id ⇒ String
identifier of the virtual machine image for the compute nodes.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for ImageReference class as Ruby Hash.
Instance Attribute Details
#offer ⇒ String
Returns Offer. Offer of the image.
19 20 21 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/image_reference.rb', line 19 def offer @offer end |
#publisher ⇒ String
Returns Publisher. Publisher of the image.
16 17 18 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/image_reference.rb', line 16 def publisher @publisher end |
#sku ⇒ String
Returns SKU. SKU of the image.
22 23 24 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/image_reference.rb', line 22 def sku @sku end |
#version ⇒ String
Returns Version. Version of the image.
25 26 27 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/image_reference.rb', line 25 def version @version end |
#virtual_machine_image_id ⇒ String
identifier of the virtual machine image for the compute nodes. This is of the form /subscriptions/subscriptionId/resourceGroups/resourceGroup/providers/Microsoft.Compute/images/imageName. The virtual machine image must be in the same region and subscription as the cluster. For information about the firewall settings for the Batch node agent to communicate with the Batch service see docs.microsoft.com/en-us/azure/batch/batch-api-basics#virtual-network-vnet-and-firewall-configuration. Note, you need to provide publisher, offer and sku of the base OS image of which the custom image has been derived from.
37 38 39 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/image_reference.rb', line 37 def virtual_machine_image_id @virtual_machine_image_id end |
Class Method Details
.mapper ⇒ Object
Mapper for ImageReference class as Ruby Hash. This will be used for serialization/deserialization.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/image_reference.rb', line 44 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'ImageReference', type: { name: 'Composite', class_name: 'ImageReference', model_properties: { publisher: { client_side_validation: true, required: true, serialized_name: 'publisher', type: { name: 'String' } }, offer: { client_side_validation: true, required: true, serialized_name: 'offer', type: { name: 'String' } }, sku: { client_side_validation: true, required: true, serialized_name: 'sku', type: { name: 'String' } }, version: { client_side_validation: true, required: false, serialized_name: 'version', type: { name: 'String' } }, virtual_machine_image_id: { client_side_validation: true, required: false, serialized_name: 'virtualMachineImageId', type: { name: 'String' } } } } } end |