Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::JobCreateParameters
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_05_01::Models::JobCreateParameters
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb
Overview
Job creation parameters.
Instance Attribute Summary collapse
-
#caffe2settings ⇒ Caffe2Settings
Caffe2 settings.
-
#caffe_settings ⇒ CaffeSettings
Caffe settings.
-
#chainer_settings ⇒ ChainerSettings
Chainer settings.
-
#cluster ⇒ ResourceId
job will run.
-
#cntk_settings ⇒ CNTKsettings
Cognitive Toolkit) job.
-
#constraints ⇒ JobBasePropertiesConstraints
Job.
-
#container_settings ⇒ ContainerSettings
settings for the job.
-
#custom_mpi_settings ⇒ CustomMpiSettings
MPI job.
-
#custom_toolkit_settings ⇒ CustomToolkitSettings
custom tool kit job.
-
#environment_variables ⇒ Array<EnvironmentVariable>
user defined environment variables which will be setup for the job.
-
#horovod_settings ⇒ HorovodSettings
Horovod settings.
-
#input_directories ⇒ Array<InputDirectory>
directories for the job.
-
#job_preparation ⇒ JobPreparation
on each node allocated for the job before tool kit is launched.
-
#mount_volumes ⇒ MountVolumes
be used by the job.
-
#node_count ⇒ Integer
on.
-
#output_directories ⇒ Array<OutputDirectory>
directories for the job.
-
#py_torch_settings ⇒ PyTorchSettings
PyTorch settings.
-
#scheduling_priority ⇒ JobPriority
associated with the job.
-
#secrets ⇒ Array<EnvironmentVariableWithSecretValue>
user defined environment variables with secret values which will be setup for the job.
-
#std_out_err_path_prefix ⇒ String
AI service will store stdout, stderror and execution log of the job.
-
#tensor_flow_settings ⇒ TensorFlowSettings
Flow job.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for JobCreateParameters class as Ruby Hash.
Instance Attribute Details
#caffe2settings ⇒ Caffe2Settings
Returns Caffe2 settings. Settings for Caffe2 job.
55 56 57 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 55 def caffe2settings @caffe2settings end |
#caffe_settings ⇒ CaffeSettings
Returns Caffe settings. Settings for Caffe job.
52 53 54 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 52 def caffe_settings @caffe_settings end |
#chainer_settings ⇒ ChainerSettings
Returns Chainer settings. Settings for Chainer job.
58 59 60 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 58 def chainer_settings @chainer_settings end |
#cluster ⇒ ResourceId
job will run.
22 23 24 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 22 def cluster @cluster end |
#cntk_settings ⇒ CNTKsettings
Cognitive Toolkit) job.
42 43 44 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 42 def cntk_settings @cntk_settings end |
#constraints ⇒ JobBasePropertiesConstraints
Job.
99 100 101 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 99 def constraints @constraints end |
#container_settings ⇒ ContainerSettings
settings for the job. If not provided, the job will run directly on the node.
38 39 40 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 38 def container_settings @container_settings end |
#custom_mpi_settings ⇒ CustomMpiSettings
MPI job.
66 67 68 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 66 def custom_mpi_settings @custom_mpi_settings end |
#custom_toolkit_settings ⇒ CustomToolkitSettings
custom tool kit job.
62 63 64 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 62 def custom_toolkit_settings @custom_toolkit_settings end |
#environment_variables ⇒ Array<EnvironmentVariable>
user defined environment variables which will be setup for the job.
89 90 91 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 89 def environment_variables @environment_variables end |
#horovod_settings ⇒ HorovodSettings
Returns Horovod settings. Settings for Horovod job.
69 70 71 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 69 def horovod_settings @horovod_settings end |
#input_directories ⇒ Array<InputDirectory>
directories for the job.
81 82 83 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 81 def input_directories @input_directories end |
#job_preparation ⇒ JobPreparation
on each node allocated for the job before tool kit is launched.
73 74 75 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 73 def job_preparation @job_preparation end |
#mount_volumes ⇒ MountVolumes
be used by the job. These volumes will be mounted before the job execution and will be unmounted after the job completion. The volumes will be mounted at location specified by $AZ_BATCHAI_JOB_MOUNT_ROOT environment variable.
29 30 31 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 29 def mount_volumes @mount_volumes end |
#node_count ⇒ Integer
on. The job will be gang scheduled on that many compute nodes.
33 34 35 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 33 def node_count @node_count end |
#output_directories ⇒ Array<OutputDirectory>
directories for the job.
85 86 87 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 85 def output_directories @output_directories end |
#py_torch_settings ⇒ PyTorchSettings
Returns pyTorch settings. Settings for pyTorch job.
45 46 47 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 45 def py_torch_settings @py_torch_settings end |
#scheduling_priority ⇒ JobPriority
associated with the job. Possible values: low, normal, high. Possible values include: ‘low’, ‘normal’, ‘high’. Default value: ‘normal’ .
18 19 20 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 18 def scheduling_priority @scheduling_priority end |
#secrets ⇒ Array<EnvironmentVariableWithSecretValue>
user defined environment variables with secret values which will be setup for the job. Server will never report values of these variables back.
95 96 97 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 95 def secrets @secrets end |
#std_out_err_path_prefix ⇒ String
AI service will store stdout, stderror and execution log of the job.
77 78 79 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 77 def std_out_err_path_prefix @std_out_err_path_prefix end |
#tensor_flow_settings ⇒ TensorFlowSettings
Flow job.
49 50 51 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 49 def tensor_flow_settings @tensor_flow_settings end |
Class Method Details
.mapper ⇒ Object
Mapper for JobCreateParameters class as Ruby Hash. This will be used for serialization/deserialization.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/job_create_parameters.rb', line 106 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'JobCreateParameters', type: { name: 'Composite', class_name: 'JobCreateParameters', model_properties: { scheduling_priority: { client_side_validation: true, required: false, serialized_name: 'properties.schedulingPriority', default_value: 'normal', type: { name: 'String' } }, cluster: { client_side_validation: true, required: true, serialized_name: 'properties.cluster', type: { name: 'Composite', class_name: 'ResourceId' } }, mount_volumes: { client_side_validation: true, required: false, serialized_name: 'properties.mountVolumes', type: { name: 'Composite', class_name: 'MountVolumes' } }, node_count: { client_side_validation: true, required: true, serialized_name: 'properties.nodeCount', type: { name: 'Number' } }, container_settings: { client_side_validation: true, required: false, serialized_name: 'properties.containerSettings', type: { name: 'Composite', class_name: 'ContainerSettings' } }, cntk_settings: { client_side_validation: true, required: false, serialized_name: 'properties.cntkSettings', type: { name: 'Composite', class_name: 'CNTKsettings' } }, py_torch_settings: { client_side_validation: true, required: false, serialized_name: 'properties.pyTorchSettings', type: { name: 'Composite', class_name: 'PyTorchSettings' } }, tensor_flow_settings: { client_side_validation: true, required: false, serialized_name: 'properties.tensorFlowSettings', type: { name: 'Composite', class_name: 'TensorFlowSettings' } }, caffe_settings: { client_side_validation: true, required: false, serialized_name: 'properties.caffeSettings', type: { name: 'Composite', class_name: 'CaffeSettings' } }, caffe2settings: { client_side_validation: true, required: false, serialized_name: 'properties.caffe2Settings', type: { name: 'Composite', class_name: 'Caffe2Settings' } }, chainer_settings: { client_side_validation: true, required: false, serialized_name: 'properties.chainerSettings', type: { name: 'Composite', class_name: 'ChainerSettings' } }, custom_toolkit_settings: { client_side_validation: true, required: false, serialized_name: 'properties.customToolkitSettings', type: { name: 'Composite', class_name: 'CustomToolkitSettings' } }, custom_mpi_settings: { client_side_validation: true, required: false, serialized_name: 'properties.customMpiSettings', type: { name: 'Composite', class_name: 'CustomMpiSettings' } }, horovod_settings: { client_side_validation: true, required: false, serialized_name: 'properties.horovodSettings', type: { name: 'Composite', class_name: 'HorovodSettings' } }, job_preparation: { client_side_validation: true, required: false, serialized_name: 'properties.jobPreparation', type: { name: 'Composite', class_name: 'JobPreparation' } }, std_out_err_path_prefix: { client_side_validation: true, required: true, serialized_name: 'properties.stdOutErrPathPrefix', type: { name: 'String' } }, input_directories: { client_side_validation: true, required: false, serialized_name: 'properties.inputDirectories', type: { name: 'Sequence', element: { client_side_validation: true, required: false, serialized_name: 'InputDirectoryElementType', type: { name: 'Composite', class_name: 'InputDirectory' } } } }, output_directories: { client_side_validation: true, required: false, serialized_name: 'properties.outputDirectories', type: { name: 'Sequence', element: { client_side_validation: true, required: false, serialized_name: 'OutputDirectoryElementType', type: { name: 'Composite', class_name: 'OutputDirectory' } } } }, environment_variables: { client_side_validation: true, required: false, serialized_name: 'properties.environmentVariables', type: { name: 'Sequence', element: { client_side_validation: true, required: false, serialized_name: 'EnvironmentVariableElementType', type: { name: 'Composite', class_name: 'EnvironmentVariable' } } } }, secrets: { client_side_validation: true, required: false, serialized_name: 'properties.secrets', type: { name: 'Sequence', element: { client_side_validation: true, required: false, serialized_name: 'EnvironmentVariableWithSecretValueElementType', type: { name: 'Composite', class_name: 'EnvironmentVariableWithSecretValue' } } } }, constraints: { client_side_validation: true, required: false, serialized_name: 'properties.constraints', type: { name: 'Composite', class_name: 'JobBasePropertiesConstraints' } } } } } end |