Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::NodeSetup

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-05-01/generated/azure_mgmt_batchai/models/node_setup.rb

Overview

Node setup settings.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#mount_volumesMountVolumes

setup task and all jobs executing on the cluster. The volumes will be mounted at location specified by $AZ_BATCHAI_MOUNT_ROOT environment variable.

Returns:

  • (MountVolumes)

    Mount volumes. Mount volumes to be available to



26
27
28
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/node_setup.rb', line 26

def mount_volumes
  @mount_volumes
end

#performance_counters_settingsPerformanceCountersSettings

Settings for performance counters collecting and uploading.

Returns:



30
31
32
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/node_setup.rb', line 30

def performance_counters_settings
  @performance_counters_settings
end

#setup_taskSetupTask

nodes got created or rebooted. The setup task code needs to be idempotent. Generally the setup task is used to download static data that is required for all jobs that run on the cluster VMs and/or to download/install software.

Returns:

  • (SetupTask)

    Setup task. Setup task to run on cluster nodes when



20
21
22
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/node_setup.rb', line 20

def setup_task
  @setup_task
end

Class Method Details

.mapperObject

Mapper for NodeSetup class as Ruby Hash. This will be used for serialization/deserialization.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/node_setup.rb', line 37

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'NodeSetup',
    type: {
      name: 'Composite',
      class_name: 'NodeSetup',
      model_properties: {
        setup_task: {
          client_side_validation: true,
          required: false,
          serialized_name: 'setupTask',
          type: {
            name: 'Composite',
            class_name: 'SetupTask'
          }
        },
        mount_volumes: {
          client_side_validation: true,
          required: false,
          serialized_name: 'mountVolumes',
          type: {
            name: 'Composite',
            class_name: 'MountVolumes'
          }
        },
        performance_counters_settings: {
          client_side_validation: true,
          required: false,
          serialized_name: 'performanceCountersSettings',
          type: {
            name: 'Composite',
            class_name: 'PerformanceCountersSettings'
          }
        }
      }
    }
  }
end