Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::SetupTask

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-05-01/generated/azure_mgmt_batchai/models/setup_task.rb

Overview

Specifies a setup task which can be used to customize the compute nodes of the cluster.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#command_lineString

cluster’s node after it being allocated or rebooted. The command is executed in a bash subshell as a root.

Returns:

  • (String)

    Command line. The command line to be executed on each



19
20
21
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 19

def command_line
  @command_line
end

#environment_variablesArray<EnvironmentVariable>

collection of user defined environment variables to be set for setup task.

Returns:



24
25
26
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 24

def environment_variables
  @environment_variables
end

#secretsArray<EnvironmentVariableWithSecretValue>

collection of user defined environment variables with secret values to be set for the setup task. Server will never report values of these variables back.

Returns:



30
31
32
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 30

def secrets
  @secrets
end

#std_out_err_path_prefixString

Batch AI service will upload the stdout, stderr and execution log of the setup task.

Returns:

  • (String)

    Output path prefix. The prefix of a path where the



35
36
37
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 35

def std_out_err_path_prefix
  @std_out_err_path_prefix
end

#std_out_err_path_suffixString

AI to stdOutErrPathPrefix to form a path where stdout, stderr and execution log of the setup task will be uploaded. Batch AI creates the setup task output directories under an unique path to avoid conflicts between different clusters. The full path can be obtained by concatenation of stdOutErrPathPrefix and stdOutErrPathSuffix.

Returns:

  • (String)

    Output path suffix. A path segment appended by Batch



43
44
45
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 43

def std_out_err_path_suffix
  @std_out_err_path_suffix
end

Class Method Details

.mapperObject

Mapper for SetupTask class as Ruby Hash. This will be used for serialization/deserialization.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 50

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'SetupTask',
    type: {
      name: 'Composite',
      class_name: 'SetupTask',
      model_properties: {
        command_line: {
          client_side_validation: true,
          required: true,
          serialized_name: 'commandLine',
          type: {
            name: 'String'
          }
        },
        environment_variables: {
          client_side_validation: true,
          required: false,
          serialized_name: 'environmentVariables',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'EnvironmentVariableElementType',
                type: {
                  name: 'Composite',
                  class_name: 'EnvironmentVariable'
                }
            }
          }
        },
        secrets: {
          client_side_validation: true,
          required: false,
          serialized_name: 'secrets',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'EnvironmentVariableWithSecretValueElementType',
                type: {
                  name: 'Composite',
                  class_name: 'EnvironmentVariableWithSecretValue'
                }
            }
          }
        },
        std_out_err_path_prefix: {
          client_side_validation: true,
          required: true,
          serialized_name: 'stdOutErrPathPrefix',
          type: {
            name: 'String'
          }
        },
        std_out_err_path_suffix: {
          client_side_validation: true,
          required: false,
          read_only: true,
          serialized_name: 'stdOutErrPathSuffix',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end