Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::TensorFlowSettings

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-05-01/generated/azure_mgmt_batchai/models/tensor_flow_settings.rb

Overview

TensorFlow job settings.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#master_command_line_argsString

that need to be passed to the python script for the master task.

Returns:

  • (String)

    Master command line arguments. Command line arguments



24
25
26
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/tensor_flow_settings.rb', line 24

def master_command_line_args
  @master_command_line_args
end

#parameter_server_command_line_argsString

arguments that need to be passed to the python script for the parameter server. Optional for single process jobs.

Returns:

  • (String)

    Parameter server command line arguments. Command line



34
35
36
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/tensor_flow_settings.rb', line 34

def parameter_server_command_line_args
  @parameter_server_command_line_args
end

#parameter_server_countInteger

server tasks. If specified, the value must be less than or equal to nodeCount. If not specified, the default value is equal to 1 for distributed TensorFlow training. This property can be specified only for distributed TensorFlow training.

Returns:

  • (Integer)

    Parameter server count. The number of parameter



48
49
50
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/tensor_flow_settings.rb', line 48

def parameter_server_count
  @parameter_server_count
end

#python_interpreter_pathString

interpreter.

Returns:

  • (String)

    Python interpreter path. The path to the Python



20
21
22
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/tensor_flow_settings.rb', line 20

def python_interpreter_path
  @python_interpreter_path
end

#python_script_file_pathString

Returns Python script file path. The python script to execute.

Returns:

  • (String)

    Python script file path. The python script to execute.



16
17
18
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/tensor_flow_settings.rb', line 16

def python_script_file_path
  @python_script_file_path
end

#worker_command_line_argsString

that need to be passed to the python script for the worker task. Optional for single process jobs.

Returns:

  • (String)

    Worker command line arguments. Command line arguments



29
30
31
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/tensor_flow_settings.rb', line 29

def worker_command_line_args
  @worker_command_line_args
end

#worker_countInteger

specified, the value must be less than or equal to (nodeCount * numberOfGPUs per VM). If not specified, the default value is equal to nodeCount. This property can be specified only for distributed TensorFlow training.

Returns:

  • (Integer)

    Worker count. The number of worker tasks. If



41
42
43
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/tensor_flow_settings.rb', line 41

def worker_count
  @worker_count
end

Class Method Details

.mapperObject

Mapper for TensorFlowSettings class as Ruby Hash. This will be used for serialization/deserialization.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/tensor_flow_settings.rb', line 55

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'TensorFlowSettings',
    type: {
      name: 'Composite',
      class_name: 'TensorFlowSettings',
      model_properties: {
        python_script_file_path: {
          client_side_validation: true,
          required: true,
          serialized_name: 'pythonScriptFilePath',
          type: {
            name: 'String'
          }
        },
        python_interpreter_path: {
          client_side_validation: true,
          required: false,
          serialized_name: 'pythonInterpreterPath',
          type: {
            name: 'String'
          }
        },
        master_command_line_args: {
          client_side_validation: true,
          required: false,
          serialized_name: 'masterCommandLineArgs',
          type: {
            name: 'String'
          }
        },
        worker_command_line_args: {
          client_side_validation: true,
          required: false,
          serialized_name: 'workerCommandLineArgs',
          type: {
            name: 'String'
          }
        },
        parameter_server_command_line_args: {
          client_side_validation: true,
          required: false,
          serialized_name: 'parameterServerCommandLineArgs',
          type: {
            name: 'String'
          }
        },
        worker_count: {
          client_side_validation: true,
          required: false,
          serialized_name: 'workerCount',
          type: {
            name: 'Number'
          }
        },
        parameter_server_count: {
          client_side_validation: true,
          required: false,
          serialized_name: 'parameterServerCount',
          type: {
            name: 'Number'
          }
        }
      }
    }
  }
end