Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::UnmanagedFileSystemReference

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-05-01/generated/azure_mgmt_batchai/models/unmanaged_file_system_reference.rb

Overview

Unmanaged file system mounting configuration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#mount_commandString

append mount path to the command on its own.

Returns:

  • (String)

    Mount command. Mount command line. Note, Batch AI will



17
18
19
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/unmanaged_file_system_reference.rb', line 17

def mount_command
  @mount_command
end

#relative_mount_pathString

node where the unmanaged file system will be mounted. Note that all cluster level unmanaged file systems will be mounted under $AZ_BATCHAI_MOUNT_ROOT location and all job level unmanaged file systems will be mounted under $AZ_BATCHAI_JOB_MOUNT_ROOT.

Returns:

  • (String)

    Relative mount path. The relative path on the compute



24
25
26
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/unmanaged_file_system_reference.rb', line 24

def relative_mount_path
  @relative_mount_path
end

Class Method Details

.mapperObject

Mapper for UnmanagedFileSystemReference class as Ruby Hash. This will be used for serialization/deserialization.



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/unmanaged_file_system_reference.rb', line 31

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'UnmanagedFileSystemReference',
    type: {
      name: 'Composite',
      class_name: 'UnmanagedFileSystemReference',
      model_properties: {
        mount_command: {
          client_side_validation: true,
          required: true,
          serialized_name: 'mountCommand',
          type: {
            name: 'String'
          }
        },
        relative_mount_path: {
          client_side_validation: true,
          required: true,
          serialized_name: 'relativeMountPath',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end