Class: Azure::BatchAI::Mgmt::V2018_05_01::Workspaces
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_05_01::Workspaces
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb
Overview
The Azure BatchAI Management API.
Instance Attribute Summary collapse
-
#client ⇒ BatchAIManagementClient
readonly
Reference to the BatchAIManagementClient.
Instance Method Summary collapse
-
#begin_create(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Workspace
Creates a Workspace.
-
#begin_create_async(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Concurrent::Promise
Creates a Workspace.
-
#begin_create_with_http_info(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Creates a Workspace.
-
#begin_delete(resource_group_name, workspace_name, custom_headers: nil) ⇒ Object
Deletes a Workspace.
-
#begin_delete_async(resource_group_name, workspace_name, custom_headers: nil) ⇒ Concurrent::Promise
Deletes a Workspace.
-
#begin_delete_with_http_info(resource_group_name, workspace_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Deletes a Workspace.
-
#create(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Workspace
Creates a Workspace.
-
#create_async(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Concurrent::Promise
resource belongs.
-
#delete(resource_group_name, workspace_name, custom_headers: nil) ⇒ Object
Deletes a Workspace.
-
#delete_async(resource_group_name, workspace_name, custom_headers: nil) ⇒ Concurrent::Promise
resource belongs.
-
#get(resource_group_name, workspace_name, custom_headers: nil) ⇒ Workspace
Gets information about a Workspace.
-
#get_async(resource_group_name, workspace_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets information about a Workspace.
-
#get_with_http_info(resource_group_name, workspace_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets information about a Workspace.
-
#initialize(client) ⇒ Workspaces
constructor
Creates and initializes a new instance of the Workspaces class.
-
#list(workspaces_list_options: nil, custom_headers: nil) ⇒ Array<Workspace>
Gets a list of Workspaces associated with the given subscription.
-
#list_as_lazy(workspaces_list_options: nil, custom_headers: nil) ⇒ WorkspaceListResult
Gets a list of Workspaces associated with the given subscription.
-
#list_async(workspaces_list_options: nil, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Workspaces associated with the given subscription.
-
#list_by_resource_group(resource_group_name, workspaces_list_by_resource_group_options: nil, custom_headers: nil) ⇒ Array<Workspace>
Gets a list of Workspaces within the specified resource group.
-
#list_by_resource_group_as_lazy(resource_group_name, workspaces_list_by_resource_group_options: nil, custom_headers: nil) ⇒ WorkspaceListResult
Gets a list of Workspaces within the specified resource group.
-
#list_by_resource_group_async(resource_group_name, workspaces_list_by_resource_group_options: nil, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Workspaces within the specified resource group.
-
#list_by_resource_group_next(next_page_link, custom_headers: nil) ⇒ WorkspaceListResult
Gets a list of Workspaces within the specified resource group.
-
#list_by_resource_group_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Workspaces within the specified resource group.
-
#list_by_resource_group_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Workspaces within the specified resource group.
-
#list_by_resource_group_with_http_info(resource_group_name, workspaces_list_by_resource_group_options: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Workspaces within the specified resource group.
-
#list_next(next_page_link, custom_headers: nil) ⇒ WorkspaceListResult
Gets a list of Workspaces associated with the given subscription.
-
#list_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Workspaces associated with the given subscription.
-
#list_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Workspaces associated with the given subscription.
-
#list_with_http_info(workspaces_list_options: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Workspaces associated with the given subscription.
-
#update(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Workspace
Updates properties of a Workspace.
-
#update_async(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Concurrent::Promise
Updates properties of a Workspace.
-
#update_with_http_info(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Updates properties of a Workspace.
Constructor Details
#initialize(client) ⇒ Workspaces
Creates and initializes a new instance of the Workspaces class.
17 18 19 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ BatchAIManagementClient (readonly)
Returns reference to the BatchAIManagementClient.
22 23 24 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 22 def client @client end |
Instance Method Details
#begin_create(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Workspace
Creates a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
563 564 565 566 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 563 def begin_create(resource_group_name, workspace_name, parameters, custom_headers:nil) response = begin_create_async(resource_group_name, workspace_name, parameters, custom_headers:custom_headers).value! response.body unless response.nil? end |
#begin_create_async(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Concurrent::Promise
Creates a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. to the HTTP request.
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 600 def begin_create_async(resource_group_name, workspace_name, parameters, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._]+$$')).nil? fail ArgumentError, 'workspace_name is nil' if workspace_name.nil? fail ArgumentError, "'workspace_name' should satisfy the constraint - 'MaxLength': '64'" if !workspace_name.nil? && workspace_name.length > 64 fail ArgumentError, "'workspace_name' should satisfy the constraint - 'MinLength': '1'" if !workspace_name.nil? && workspace_name.length < 1 fail ArgumentError, "'workspace_name' should satisfy the constraint - 'Pattern': '^[-\w_]+$'" if !workspace_name.nil? && workspace_name.match(Regexp.new('^^[-\w_]+$$')).nil? fail ArgumentError, 'parameters is nil' if parameters.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::WorkspaceCreateParameters.mapper() request_content = @client.serialize(request_mapper, parameters) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.BatchAI/workspaces/{workspaceName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'workspaceName' => workspace_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:put, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 || status_code == 202 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::Workspace.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#begin_create_with_http_info(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Creates a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
582 583 584 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 582 def begin_create_with_http_info(resource_group_name, workspace_name, parameters, custom_headers:nil) begin_create_async(resource_group_name, workspace_name, parameters, custom_headers:custom_headers).value! end |
#begin_delete(resource_group_name, workspace_name, custom_headers: nil) ⇒ Object
Deletes a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
679 680 681 682 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 679 def begin_delete(resource_group_name, workspace_name, custom_headers:nil) response = begin_delete_async(resource_group_name, workspace_name, custom_headers:custom_headers).value! nil end |
#begin_delete_async(resource_group_name, workspace_name, custom_headers: nil) ⇒ Concurrent::Promise
Deletes a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. to the HTTP request.
714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 714 def begin_delete_async(resource_group_name, workspace_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._]+$$')).nil? fail ArgumentError, 'workspace_name is nil' if workspace_name.nil? fail ArgumentError, "'workspace_name' should satisfy the constraint - 'MaxLength': '64'" if !workspace_name.nil? && workspace_name.length > 64 fail ArgumentError, "'workspace_name' should satisfy the constraint - 'MinLength': '1'" if !workspace_name.nil? && workspace_name.length < 1 fail ArgumentError, "'workspace_name' should satisfy the constraint - 'Pattern': '^[-\w_]+$'" if !workspace_name.nil? && workspace_name.match(Regexp.new('^^[-\w_]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.BatchAI/workspaces/{workspaceName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'workspaceName' => workspace_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:delete, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 || status_code == 202 || status_code == 204 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? result end promise.execute end |
#begin_delete_with_http_info(resource_group_name, workspace_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Deletes a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
697 698 699 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 697 def begin_delete_with_http_info(resource_group_name, workspace_name, custom_headers:nil) begin_delete_async(resource_group_name, workspace_name, custom_headers:custom_headers).value! end |
#create(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Workspace
Creates a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
241 242 243 244 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 241 def create(resource_group_name, workspace_name, parameters, custom_headers:nil) response = create_async(resource_group_name, workspace_name, parameters, custom_headers:custom_headers).value! response.body unless response.nil? end |
#create_async(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Concurrent::Promise
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
response.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 259 def create_async(resource_group_name, workspace_name, parameters, custom_headers:nil) # Send request promise = begin_create_async(resource_group_name, workspace_name, parameters, custom_headers:custom_headers) promise = promise.then do |response| # Defining deserialization method. deserialize_method = lambda do |parsed_response| result_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::Workspace.mapper() parsed_response = @client.deserialize(result_mapper, parsed_response) end # Waiting for response. @client.get_long_running_operation_result(response, deserialize_method) end promise end |
#delete(resource_group_name, workspace_name, custom_headers: nil) ⇒ Object
Deletes a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
409 410 411 412 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 409 def delete(resource_group_name, workspace_name, custom_headers:nil) response = delete_async(resource_group_name, workspace_name, custom_headers:custom_headers).value! nil end |
#delete_async(resource_group_name, workspace_name, custom_headers: nil) ⇒ Concurrent::Promise
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
response.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 426 def delete_async(resource_group_name, workspace_name, custom_headers:nil) # Send request promise = begin_delete_async(resource_group_name, workspace_name, custom_headers:custom_headers) promise = promise.then do |response| # Defining deserialization method. deserialize_method = lambda do |parsed_response| end # Waiting for response. @client.get_long_running_operation_result(response, deserialize_method) end promise end |
#get(resource_group_name, workspace_name, custom_headers: nil) ⇒ Workspace
Gets information about a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
455 456 457 458 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 455 def get(resource_group_name, workspace_name, custom_headers:nil) response = get_async(resource_group_name, workspace_name, custom_headers:custom_headers).value! response.body unless response.nil? end |
#get_async(resource_group_name, workspace_name, custom_headers: nil) ⇒ Concurrent::Promise
Gets information about a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. to the HTTP request.
490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 490 def get_async(resource_group_name, workspace_name, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._]+$$')).nil? fail ArgumentError, 'workspace_name is nil' if workspace_name.nil? fail ArgumentError, "'workspace_name' should satisfy the constraint - 'MaxLength': '64'" if !workspace_name.nil? && workspace_name.length > 64 fail ArgumentError, "'workspace_name' should satisfy the constraint - 'MinLength': '1'" if !workspace_name.nil? && workspace_name.length < 1 fail ArgumentError, "'workspace_name' should satisfy the constraint - 'Pattern': '^[-\w_]+$'" if !workspace_name.nil? && workspace_name.match(Regexp.new('^^[-\w_]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.BatchAI/workspaces/{workspaceName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'workspaceName' => workspace_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::Workspace.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_with_http_info(resource_group_name, workspace_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets information about a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. will be added to the HTTP request.
473 474 475 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 473 def get_with_http_info(resource_group_name, workspace_name, custom_headers:nil) get_async(resource_group_name, workspace_name, custom_headers:custom_headers).value! end |
#list(workspaces_list_options: nil, custom_headers: nil) ⇒ Array<Workspace>
Gets a list of Workspaces associated with the given subscription.
for the operation will be added to the HTTP request.
34 35 36 37 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 34 def list(workspaces_list_options:nil, custom_headers:nil) first_page = list_as_lazy(workspaces_list_options:, custom_headers:custom_headers) first_page.get_all_items end |
#list_as_lazy(workspaces_list_options: nil, custom_headers: nil) ⇒ WorkspaceListResult
Gets a list of Workspaces associated with the given subscription.
for the operation will be added to the HTTP request.
response.
954 955 956 957 958 959 960 961 962 963 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 954 def list_as_lazy(workspaces_list_options:nil, custom_headers:nil) response = list_async(workspaces_list_options:, custom_headers:custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_page_link| list_next_async(next_page_link, custom_headers:custom_headers) end page end end |
#list_async(workspaces_list_options: nil, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Workspaces associated with the given subscription.
for the operation to the HTTP request.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 63 def list_async(workspaces_list_options:nil, custom_headers:nil) fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? max_results = nil unless .nil? max_results = .maxResults end request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/providers/Microsoft.BatchAI/workspaces' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version,'maxresults' => max_results}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::WorkspaceListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_resource_group(resource_group_name, workspaces_list_by_resource_group_options: nil, custom_headers: nil) ⇒ Array<Workspace>
Gets a list of Workspaces within the specified resource group.
resource belongs.
- WorkspacesListByResourceGroupOptions
-
Additional parameters for the
operation will be added to the HTTP request.
133 134 135 136 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 133 def list_by_resource_group(resource_group_name, workspaces_list_by_resource_group_options:nil, custom_headers:nil) first_page = list_by_resource_group_as_lazy(resource_group_name, workspaces_list_by_resource_group_options:, custom_headers:custom_headers) first_page.get_all_items end |
#list_by_resource_group_as_lazy(resource_group_name, workspaces_list_by_resource_group_options: nil, custom_headers: nil) ⇒ WorkspaceListResult
Gets a list of Workspaces within the specified resource group.
resource belongs.
- WorkspacesListByResourceGroupOptions
-
Additional parameters for the
operation will be added to the HTTP request.
response.
979 980 981 982 983 984 985 986 987 988 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 979 def list_by_resource_group_as_lazy(resource_group_name, workspaces_list_by_resource_group_options:nil, custom_headers:nil) response = list_by_resource_group_async(resource_group_name, workspaces_list_by_resource_group_options:, custom_headers:custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_page_link| list_by_resource_group_next_async(next_page_link, custom_headers:custom_headers) end page end end |
#list_by_resource_group_async(resource_group_name, workspaces_list_by_resource_group_options: nil, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Workspaces within the specified resource group.
resource belongs.
- WorkspacesListByResourceGroupOptions
-
Additional parameters for the
operation to the HTTP request.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 168 def list_by_resource_group_async(resource_group_name, workspaces_list_by_resource_group_options:nil, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._]+$$')).nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? max_results = nil unless .nil? max_results = .maxResults end request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.BatchAI/workspaces' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version,'maxresults' => max_results}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::WorkspaceListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_resource_group_next(next_page_link, custom_headers: nil) ⇒ WorkspaceListResult
Gets a list of Workspaces within the specified resource group.
to List operation. will be added to the HTTP request.
863 864 865 866 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 863 def list_by_resource_group_next(next_page_link, custom_headers:nil) response = list_by_resource_group_next_async(next_page_link, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_by_resource_group_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Workspaces within the specified resource group.
to List operation. to the HTTP request.
892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 892 def list_by_resource_group_next_async(next_page_link, custom_headers:nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::WorkspaceListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_by_resource_group_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Workspaces within the specified resource group.
to List operation. will be added to the HTTP request.
878 879 880 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 878 def list_by_resource_group_next_with_http_info(next_page_link, custom_headers:nil) list_by_resource_group_next_async(next_page_link, custom_headers:custom_headers).value! end |
#list_by_resource_group_with_http_info(resource_group_name, workspaces_list_by_resource_group_options: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Workspaces within the specified resource group.
resource belongs.
- WorkspacesListByResourceGroupOptions
-
Additional parameters for the
operation will be added to the HTTP request.
151 152 153 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 151 def list_by_resource_group_with_http_info(resource_group_name, workspaces_list_by_resource_group_options:nil, custom_headers:nil) list_by_resource_group_async(resource_group_name, workspaces_list_by_resource_group_options:, custom_headers:custom_headers).value! end |
#list_next(next_page_link, custom_headers: nil) ⇒ WorkspaceListResult
Gets a list of Workspaces associated with the given subscription.
to List operation. will be added to the HTTP request.
773 774 775 776 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 773 def list_next(next_page_link, custom_headers:nil) response = list_next_async(next_page_link, custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise
Gets a list of Workspaces associated with the given subscription.
to List operation. to the HTTP request.
802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 802 def list_next_async(next_page_link, custom_headers:nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::WorkspaceListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Workspaces associated with the given subscription.
to List operation. will be added to the HTTP request.
788 789 790 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 788 def list_next_with_http_info(next_page_link, custom_headers:nil) list_next_async(next_page_link, custom_headers:custom_headers).value! end |
#list_with_http_info(workspaces_list_options: nil, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Gets a list of Workspaces associated with the given subscription.
for the operation will be added to the HTTP request.
49 50 51 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 49 def list_with_http_info(workspaces_list_options:nil, custom_headers:nil) list_async(workspaces_list_options:, custom_headers:custom_headers).value! end |
#update(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Workspace
Updates properties of a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. workspace update. will be added to the HTTP request.
292 293 294 295 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 292 def update(resource_group_name, workspace_name, parameters, custom_headers:nil) response = update_async(resource_group_name, workspace_name, parameters, custom_headers:custom_headers).value! response.body unless response.nil? end |
#update_async(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ Concurrent::Promise
Updates properties of a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. workspace update. to the HTTP request.
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 331 def update_async(resource_group_name, workspace_name, parameters, custom_headers:nil) fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, "'resource_group_name' should satisfy the constraint - 'Pattern': '^[-\w\._]+$'" if !resource_group_name.nil? && resource_group_name.match(Regexp.new('^^[-\w\._]+$$')).nil? fail ArgumentError, 'workspace_name is nil' if workspace_name.nil? fail ArgumentError, "'workspace_name' should satisfy the constraint - 'MaxLength': '64'" if !workspace_name.nil? && workspace_name.length > 64 fail ArgumentError, "'workspace_name' should satisfy the constraint - 'MinLength': '1'" if !workspace_name.nil? && workspace_name.length < 1 fail ArgumentError, "'workspace_name' should satisfy the constraint - 'Pattern': '^[-\w_]+$'" if !workspace_name.nil? && workspace_name.match(Regexp.new('^^[-\w_]+$$')).nil? fail ArgumentError, 'parameters is nil' if parameters.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? # Serialize Request request_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::WorkspaceUpdateParameters.mapper() request_content = @client.serialize(request_mapper, parameters) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.BatchAI/workspaces/{workspaceName}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'resourceGroupName' => resource_group_name,'workspaceName' => workspace_name,'subscriptionId' => @client.subscription_id}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:patch, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::BatchAI::Mgmt::V2018_05_01::Models::Workspace.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#update_with_http_info(resource_group_name, workspace_name, parameters, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Updates properties of a Workspace.
resource belongs. only contain a combination of alphanumeric characters along with dash (-) and underscore (_). The name must be from 1 through 64 characters long. workspace update. will be added to the HTTP request.
312 313 314 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/workspaces.rb', line 312 def update_with_http_info(resource_group_name, workspace_name, parameters, custom_headers:nil) update_async(resource_group_name, workspace_name, parameters, custom_headers:custom_headers).value! end |