Class: Azure::BatchAI::Mgmt::V2018_03_01::Models::EnvironmentVariableWithSecretValue
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_03_01::Models::EnvironmentVariableWithSecretValue
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb
Overview
A collection of environment variables with secret values to set.
Instance Attribute Summary collapse
-
#name ⇒ String
secret value.
-
#value ⇒ String
never be reported back by Batch AI.
-
#value_secret_reference ⇒ KeyVaultSecretReference
KeyVault secret which will be used as the environment variable value.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for EnvironmentVariableWithSecretValue class as Ruby Hash.
Instance Attribute Details
#name ⇒ String
secret value.
17 18 19 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 17 def name @name end |
#value ⇒ String
never be reported back by Batch AI.
21 22 23 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 21 def value @value end |
#value_secret_reference ⇒ KeyVaultSecretReference
KeyVault secret which will be used as the environment variable value. Specifies KeyVault Store and Secret which contains the value for the environment variable. One of value or valueSecretReference must be provided.
28 29 30 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 28 def value_secret_reference @value_secret_reference end |
Class Method Details
.mapper ⇒ Object
Mapper for EnvironmentVariableWithSecretValue class as Ruby Hash. This will be used for serialization/deserialization.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 35 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'EnvironmentVariableWithSecretValue', type: { name: 'Composite', class_name: 'EnvironmentVariableWithSecretValue', model_properties: { name: { client_side_validation: true, required: true, serialized_name: 'name', type: { name: 'String' } }, value: { client_side_validation: true, required: false, serialized_name: 'value', type: { name: 'String' } }, value_secret_reference: { client_side_validation: true, required: false, serialized_name: 'valueSecretReference', type: { name: 'Composite', class_name: 'KeyVaultSecretReference' } } } } } end |