Class: Azure::BatchAI::Mgmt::V2018_03_01::Models::OutputDirectory
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_03_01::Models::OutputDirectory
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-03-01/generated/azure_mgmt_batchai/models/output_directory.rb
Overview
Output directory for the job.
Instance Attribute Summary collapse
-
#create_new ⇒ Boolean
false, then the directory is not created and can be any directory path that the user specifies.
-
#id ⇒ String
output directory will be available as a value of an environment variable with AZ_BATCHAI_OUTPUT_<id> name, where <id> is the value of id attribute.
-
#path_prefix ⇒ String
created.
-
#path_suffix ⇒ String
created.
-
#type ⇒ OutputType
output directory.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for OutputDirectory class as Ruby Hash.
Instance Attribute Details
#create_new ⇒ Boolean
false, then the directory is not created and can be any directory path that the user specifies. Default value: true .
46 47 48 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/output_directory.rb', line 46 def create_new @create_new end |
#id ⇒ String
output directory will be available as a value of an environment variable with AZ_BATCHAI_OUTPUT_<id> name, where <id> is the value of id attribute.
19 20 21 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/output_directory.rb', line 19 def id @id end |
#path_prefix ⇒ String
created. NOTE: This is an absolute path to prefix. E.g. $AZ_BATCHAI_MOUNT_ROOT/MyNFS/MyLogs. You can find the full path to the output directory by combining pathPrefix, jobOutputDirectoryPathSegment (reported by get job) and pathSuffix.
26 27 28 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/output_directory.rb', line 26 def path_prefix @path_prefix end |
#path_suffix ⇒ String
created. The suffix path where the output directory will be created. E.g. models. You can find the full path to the output directory by combining pathPrefix, jobOutputDirectoryPathSegment (reported by get job) and pathSuffix.
33 34 35 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/output_directory.rb', line 33 def path_suffix @path_suffix end |
#type ⇒ OutputType
output directory. Default value is Custom. The possible values are Model, Logs, Summary, and Custom. Users can use multiple enums for a single directory. Eg. outPutType=‘Model,Logs, Summary’. Possible values include: ‘model’, ‘logs’, ‘summary’, ‘custom’. Default value: ‘custom’ .
41 42 43 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/output_directory.rb', line 41 def type @type end |
Class Method Details
.mapper ⇒ Object
Mapper for OutputDirectory class as Ruby Hash. This will be used for serialization/deserialization.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/output_directory.rb', line 53 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'OutputDirectory', type: { name: 'Composite', class_name: 'OutputDirectory', model_properties: { id: { client_side_validation: true, required: true, serialized_name: 'id', type: { name: 'String' } }, path_prefix: { client_side_validation: true, required: true, serialized_name: 'pathPrefix', type: { name: 'String' } }, path_suffix: { client_side_validation: true, required: false, serialized_name: 'pathSuffix', type: { name: 'String' } }, type: { client_side_validation: true, required: false, serialized_name: 'type', default_value: 'custom', type: { name: 'String' } }, create_new: { client_side_validation: true, required: false, serialized_name: 'createNew', default_value: true, type: { name: 'Boolean' } } } } } end |