Class: Azure::BatchAI::Mgmt::V2018_03_01::Models::PyTorchSettings
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_03_01::Models::PyTorchSettings
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-03-01/generated/azure_mgmt_batchai/models/py_torch_settings.rb
Overview
Specifies the settings for pyTorch job.
Instance Attribute Summary collapse
-
#command_line_args ⇒ String
task.
-
#communication_backend ⇒ String
jobs.
-
#process_count ⇒ Integer
The default value for this property is equal to nodeCount property.
-
#python_interpreter_path ⇒ String
The path to python interpreter.
-
#python_script_file_path ⇒ String
the job.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for PyTorchSettings class as Ruby Hash.
Instance Attribute Details
#command_line_args ⇒ String
task.
24 25 26 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/py_torch_settings.rb', line 24 def command_line_args @command_line_args end |
#communication_backend ⇒ String
jobs. Valid values are ‘TCP’, ‘Gloo’ or ‘MPI’. Not required for non-distributed jobs.
33 34 35 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/py_torch_settings.rb', line 33 def communication_backend @communication_backend end |
#process_count ⇒ Integer
The default value for this property is equal to nodeCount property.
28 29 30 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/py_torch_settings.rb', line 28 def process_count @process_count end |
#python_interpreter_path ⇒ String
Returns The path to python interpreter.
20 21 22 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/py_torch_settings.rb', line 20 def python_interpreter_path @python_interpreter_path end |
#python_script_file_path ⇒ String
the job.
17 18 19 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/py_torch_settings.rb', line 17 def python_script_file_path @python_script_file_path end |
Class Method Details
.mapper ⇒ Object
Mapper for PyTorchSettings class as Ruby Hash. This will be used for serialization/deserialization.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/py_torch_settings.rb', line 40 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'PyTorchSettings', type: { name: 'Composite', class_name: 'PyTorchSettings', model_properties: { python_script_file_path: { client_side_validation: true, required: true, serialized_name: 'pythonScriptFilePath', type: { name: 'String' } }, python_interpreter_path: { client_side_validation: true, required: false, serialized_name: 'pythonInterpreterPath', type: { name: 'String' } }, command_line_args: { client_side_validation: true, required: false, serialized_name: 'commandLineArgs', type: { name: 'String' } }, process_count: { client_side_validation: true, required: false, serialized_name: 'processCount', type: { name: 'Number' } }, communication_backend: { client_side_validation: true, required: false, serialized_name: 'communicationBackend', type: { name: 'String' } } } } } end |