Class: Azure::BatchAI::Mgmt::V2018_03_01::Models::SetupTask
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_03_01::Models::SetupTask
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-03-01/generated/azure_mgmt_batchai/models/setup_task.rb
Overview
Specifies a setup task which can be used to customize the compute nodes of the cluster.
Instance Attribute Summary collapse
-
#command_line ⇒ String
Command Line to start Setup process.
-
#environment_variables ⇒ Array<EnvironmentVariable>
variables to be set for setup task.
-
#run_elevated ⇒ Boolean
account.
-
#secrets ⇒ Array<EnvironmentVariableWithSecretValue>
environment variables with secret values to be set for setup task.
-
#std_out_err_path_prefix ⇒ String
upload the stdout and stderr of the setup task.
-
#std_out_err_path_suffix ⇒ String
stdOutErrPathPrefix to form a path where stdout and stderr of the setup task will be uploaded.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for SetupTask class as Ruby Hash.
Instance Attribute Details
#command_line ⇒ String
Returns Command Line to start Setup process.
17 18 19 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 17 def command_line @command_line end |
#environment_variables ⇒ Array<EnvironmentVariable>
variables to be set for setup task.
21 22 23 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 21 def environment_variables @environment_variables end |
#run_elevated ⇒ Boolean
account. The default value is false. Note. Non-elevated tasks are run under an account added into sudoer list and can perform sudo when required. Default value: false .
32 33 34 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 32 def run_elevated @run_elevated end |
#secrets ⇒ Array<EnvironmentVariableWithSecretValue>
environment variables with secret values to be set for setup task. Server will never report values of these variables back.
26 27 28 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 26 def secrets @secrets end |
#std_out_err_path_prefix ⇒ String
upload the stdout and stderr of the setup task.
36 37 38 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 36 def std_out_err_path_prefix @std_out_err_path_prefix end |
#std_out_err_path_suffix ⇒ String
stdOutErrPathPrefix to form a path where stdout and stderr of the setup task will be uploaded. Batch AI creates the setup task output directories under an unique path to avoid conflicts between different clusters. You can concatenate stdOutErrPathPrefix and stdOutErrPathSuffix to get the full path to the output directory.
44 45 46 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 44 def std_out_err_path_suffix @std_out_err_path_suffix end |
Class Method Details
.mapper ⇒ Object
Mapper for SetupTask class as Ruby Hash. This will be used for serialization/deserialization.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/2018-03-01/generated/azure_mgmt_batchai/models/setup_task.rb', line 51 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'SetupTask', type: { name: 'Composite', class_name: 'SetupTask', model_properties: { command_line: { client_side_validation: true, required: true, serialized_name: 'commandLine', type: { name: 'String' } }, environment_variables: { client_side_validation: true, required: false, serialized_name: 'environmentVariables', type: { name: 'Sequence', element: { client_side_validation: true, required: false, serialized_name: 'EnvironmentVariableElementType', type: { name: 'Composite', class_name: 'EnvironmentVariable' } } } }, secrets: { client_side_validation: true, required: false, serialized_name: 'secrets', type: { name: 'Sequence', element: { client_side_validation: true, required: false, serialized_name: 'EnvironmentVariableWithSecretValueElementType', type: { name: 'Composite', class_name: 'EnvironmentVariableWithSecretValue' } } } }, run_elevated: { client_side_validation: true, required: false, serialized_name: 'runElevated', default_value: false, type: { name: 'Boolean' } }, std_out_err_path_prefix: { client_side_validation: true, required: true, serialized_name: 'stdOutErrPathPrefix', type: { name: 'String' } }, std_out_err_path_suffix: { client_side_validation: true, required: false, read_only: true, serialized_name: 'stdOutErrPathSuffix', type: { name: 'String' } } } } } end |