Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::EnvironmentVariableWithSecretValue
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_05_01::Models::EnvironmentVariableWithSecretValue
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-05-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb
Overview
An environment variable with secret value definition.
Instance Attribute Summary collapse
-
#name ⇒ String
the secret value.
-
#value ⇒ String
value will never be reported back by Batch AI.
-
#value_secret_reference ⇒ KeyVaultSecretReference
store and secret which contains the value for the environment variable.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for EnvironmentVariableWithSecretValue class as Ruby Hash.
Instance Attribute Details
#name ⇒ String
the secret value.
17 18 19 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 17 def name @name end |
#value ⇒ String
value will never be reported back by Batch AI.
21 22 23 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 21 def value @value end |
#value_secret_reference ⇒ KeyVaultSecretReference
store and secret which contains the value for the environment variable. One of value or valueSecretReference must be provided.
26 27 28 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 26 def value_secret_reference @value_secret_reference end |
Class Method Details
.mapper ⇒ Object
Mapper for EnvironmentVariableWithSecretValue class as Ruby Hash. This will be used for serialization/deserialization.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/environment_variable_with_secret_value.rb', line 33 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'EnvironmentVariableWithSecretValue', type: { name: 'Composite', class_name: 'EnvironmentVariableWithSecretValue', model_properties: { name: { client_side_validation: true, required: true, serialized_name: 'name', type: { name: 'String' } }, value: { client_side_validation: true, required: false, serialized_name: 'value', type: { name: 'String' } }, value_secret_reference: { client_side_validation: true, required: false, serialized_name: 'valueSecretReference', type: { name: 'Composite', class_name: 'KeyVaultSecretReference' } } } } } end |