Class: Azure::BatchAI::Mgmt::V2018_05_01::Models::JobsListOutputFilesOptions
- Inherits:
-
Object
- Object
- Azure::BatchAI::Mgmt::V2018_05_01::Models::JobsListOutputFilesOptions
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-05-01/generated/azure_mgmt_batchai/models/jobs_list_output_files_options.rb
Overview
Additional parameters for list_output_files operation.
Instance Attribute Summary collapse
-
#directory ⇒ String
The path to the directory.
-
#linkexpiryinminutes ⇒ Integer
will expire.
-
#max_results ⇒ Integer
response.
-
#outputdirectoryid ⇒ String
OutputDirectory–>id parameter that is given by the user during Create Job.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for JobsListOutputFilesOptions class as Ruby Hash.
Instance Attribute Details
#directory ⇒ String
Returns The path to the directory. Default value: ‘.’ .
21 22 23 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/jobs_list_output_files_options.rb', line 21 def directory @directory end |
#linkexpiryinminutes ⇒ Integer
will expire. Default value: 60 .
25 26 27 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/jobs_list_output_files_options.rb', line 25 def end |
#max_results ⇒ Integer
response. A maximum of 1000 files can be returned. Default value: 1000 .
30 31 32 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/jobs_list_output_files_options.rb', line 30 def max_results @max_results end |
#outputdirectoryid ⇒ String
OutputDirectory–>id parameter that is given by the user during Create Job.
18 19 20 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/jobs_list_output_files_options.rb', line 18 def outputdirectoryid @outputdirectoryid end |
Class Method Details
.mapper ⇒ Object
Mapper for JobsListOutputFilesOptions class as Ruby Hash. This will be used for serialization/deserialization.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/2018-05-01/generated/azure_mgmt_batchai/models/jobs_list_output_files_options.rb', line 37 def self.mapper() { client_side_validation: true, required: false, type: { name: 'Composite', class_name: 'JobsListOutputFilesOptions', model_properties: { outputdirectoryid: { client_side_validation: true, required: true, type: { name: 'String' } }, directory: { client_side_validation: true, required: false, default_value: '.', type: { name: 'String' } }, linkexpiryinminutes: { client_side_validation: true, required: false, default_value: 60, type: { name: 'Number' } }, max_results: { client_side_validation: true, required: false, default_value: 1000, type: { name: 'Number' } } } } } end |